print_banner

Function print_banner 

pub fn print_banner()
Display the ASCII art banner

Prints a centered, coloured ASCII art banner. The banner is used at the very start of initializing the server to give it a unique and identifiable look in the terminal. The ASCII art is generated from https://patorjk.com/software/taag/#p=display

Example

print_banner();